@@ -9,7 +9,7 @@ use Module::Runtime;
 use Params::Util 0.14 ();
 use Try::Tiny;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 has driver => (
     is      => 'ro',
@@ -120,7 +120,7 @@ Parcel::Track - Driver-based API for tracking parcel
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -272,10 +272,26 @@ L<Parcel::Track::KR::CJKorea>
 
 =item *
 
+L<Parcel::Track::KR::Dongbu>
+
+=item *
+
+L<Parcel::Track::KR::Hanjin>
+
+=item *
+
+L<Parcel::Track::KR::KGB>
+
+=item *
+
 L<Parcel::Track::KR::PostOffice>
 
 =item *
 
+L<Parcel::Track::KR::Yellowcap>
+
+=item *
+
 L<SMS::Send>
 
 =back
